==> qtwebengine-opensource-src_5.7.1+dfsg.orig.tar.xz: qtwebengine-opensource-src-5.7.1/src/core/renderer/render_view_observer_qt.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the QtWebEngine module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/
#ifndef RENDER_VIEW_OBSERVER_QT_H
#define RENDER_VIEW_OBSERVER_QT_H

#include "content/public/renderer/render_view_observer.h"

#include <QtGlobal>

namespace web_cache {
class WebCacheRenderProcessObserver;
}

class RenderViewObserverQt : public content::RenderViewObserver {
public:
    RenderViewObserverQt(content::RenderView* render_view,
                         web_cache::WebCacheRenderProcessObserver* web_cache_render_process_observer);

private:
    void onFetchDocumentMarkup(quint64 requestId);
    void onFetchDocumentInnerText(quint64 requestId);
    void onSetBackgroundColor(quint32 color);

    void OnFirstVisuallyNonEmptyLayout() Q_DECL_OVERRIDE;

    virtual bool OnMessageReceived(const IPC::Message& message) Q_DECL_OVERRIDE;
    virtual void Navigate(const GURL& url) Q_DECL_OVERRIDE;

    web_cache::WebCacheRenderProcessObserver* m_web_cache_render_process_observer;

    DISALLOW_COPY_AND_ASSIGN(RenderViewObserverQt);
};

#endif // RENDER_VIEW_OBSERVER_QT_H

==> qtwebengine-opensource-src_5.9.5+dfsg.orig.tar.xz: qtwebengine-opensource-src-5.9.5/src/core/renderer/render_view_observer_qt.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the QtWebEngine module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/
#ifndef RENDER_VIEW_OBSERVER_QT_H
#define RENDER_VIEW_OBSERVER_QT_H

#include "content/public/renderer/render_view_observer.h"

#include <QtGlobal>

namespace web_cache {
class WebCacheImpl;
}

class RenderViewObserverQt : public content::RenderViewObserver {
public:
    RenderViewObserverQt(content::RenderView* render_view,
                         web_cache::WebCacheImpl* web_cache_impl);

private:
    void onFetchDocumentMarkup(quint64 requestId);
    void onFetchDocumentInnerText(quint64 requestId);
    void onSetBackgroundColor(quint32 color);

    void OnDestruct() override { }

    bool OnMessageReceived(const IPC::Message& message) override;
    void Navigate(const GURL& url) override;

    web_cache::WebCacheImpl* m_web_cache_impl;

    DISALLOW_COPY_AND_ASSIGN(RenderViewObserverQt);
};

#endif // RENDER_VIEW_OBSERVER_QT_H
